==> tdesvn-trinity-14.0.9.tar.xz: tdesvn-trinity-14.0.9/src/svnfrontend/fronthelpers/propertylist.h <==
/***************************************************************************
 *   Copyright (C) 2007 by Rajko Albrecht  ral@alwins-world.de             *
 *   http://tdesvn.alwins-world.de/                                        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/
#ifndef PROPERTYLIST_H
#define PROPERTYLIST_H

#include <tdelistview.h>
#include "svnqttypes.hpp"

/**
	@author
*/
class Propertylist : public TDEListView
{
    Q_OBJECT
  
public:
    Propertylist(TQWidget *parent = 0, const char *name = 0);
    ~Propertylist();

    bool checkExisting(const TQString&aName,TQListViewItem*it=0);
    bool commitchanges()const{return m_commitit;}
    void setCommitchanges(bool how){m_commitit=how;}
    void addCallback(TQObject*);

public slots:
    virtual void displayList(const svn::PathPropertiesMapListPtr&,bool,const TQString&);
    virtual void clear();

protected slots:
    virtual void slotItemRenamed(TQListViewItem*item,const TQString & str,int col );

signals:
    void sigSetProperty(const svn::PropertiesMap&,const TQValueList<TQString>&,const TQString&);
protected:
    bool m_commitit;
    TQString m_current;
protected slots:
    virtual void slotContextMenuRequested(TQListViewItem *, const TQPoint &, int);
};

#endif

==> tdesvn-trinity-14.0.13.tar.xz: tdesvn-trinity-14.0.13/src/svnfrontend/fronthelpers/propertylist.h <==
/***************************************************************************
 *   Copyright (C) 2007 by Rajko Albrecht  ral@alwins-world.de             *
 *   http://tdesvn.alwins-world.de/                                        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/
#ifndef PROPERTYLIST_H
#define PROPERTYLIST_H

#include <tdelistview.h>
#include "svnqttypes.h"

/**
	@author
*/
class Propertylist : public TDEListView
{
    Q_OBJECT
  
public:
    Propertylist(TQWidget *parent = 0, const char *name = 0);
    ~Propertylist();

    bool checkExisting(const TQString&aName,TQListViewItem*it=0);
    bool commitchanges()const{return m_commitit;}
    void setCommitchanges(bool how){m_commitit=how;}
    void addCallback(TQObject*);

public slots:
    virtual void displayList(const svn::PathPropertiesMapListPtr&,bool,const TQString&);
    virtual void clear();

protected slots:
    virtual void slotItemRenamed(TQListViewItem*item,const TQString & str,int col );

signals:
    void sigSetProperty(const svn::PropertiesMap&,const TQValueList<TQString>&,const TQString&);
protected:
    bool m_commitit;
    TQString m_current;
protected slots:
    virtual void slotContextMenuRequested(TQListViewItem *, const TQPoint &, int);
};

#endif
